@@ -8,6 +8,8 @@ from archipelagos.common.data.filestore import FileStoreResponse, FileStoreReque
 from archipelagos.common.data.filestore import FileMetadataRequest, FileMetadataResponse
 from archipelagos.common.data.timeseries import TimeSeriesRequest, TimeSeriesResponse
 from archipelagos.common.data.timeseries import TimeSeriesMetadataRequest, TimeSeriesMetadataResponse
+from archipelagos.common.platform import HttpConstants
+from archipelagos.common.data import PYTHON_CLIENT
 
 import io
 import pandas as pd
@@ -128,14 +130,17 @@ class Archipelagos:
         if isinstance(port, int):
             base_url = "{0}:{1}".format(base_url, port)
 
+        query_params = {HttpConstants.CLIENT_TYPE_PARAMETER: PYTHON_CLIENT}
+
         for param in params:
             value = params[param]
             if value is None:
                 params[param] = ""
+            query_params[param] = value
 
         url_parts = list(urlparse(base_url))
         query = dict(parse_qsl(url_parts[4]))
-        query.update(params)
+        query.update(query_params)
         url_parts[4] = urlencode(query)
 
         return urlunparse(url_parts)
