@@ -14,6 +14,7 @@ from archipelagos.common.protobuf.common.data import DataEntry_pb2
 from archipelagos.common.protobuf.common import Timestamp_pb2
 from archipelagos.common.data import _valid_feature_value, _feature_value_equals
 from archipelagos.common.data import _get_feature_value, _get_feature_value_from_proto
+from archipelagos.common.data import PYTHON_CLIENT
 
 from archipelagos.common.data import Frequency, is_valid_token
 
@@ -945,6 +946,7 @@ class CollectionMetadataRequest:
         request.source = self._source
         request.code = self._code
         request.id = self._cid
+        request.clientType = PYTHON_CLIENT
 
         return request
 
@@ -1384,6 +1386,7 @@ class CollectionRequest:
 
         request.maxSize = self._max_size
         request.filters.update(self._filters)
+        request.clientType = PYTHON_CLIENT
 
         return request
 
