@@ -13,6 +13,7 @@ from archipelagos.common.protobuf.common.data.filestore import FileMetadataRespo
 from archipelagos.common.protobuf.common.data.filestore import FileMetadataRequest_pb2
 from archipelagos.common.protobuf.common.data.filestore import FileStoreMetadata_pb2, FileMetadata_pb2
 from archipelagos.common.protobuf.common import Timestamp_pb2
+from archipelagos.common.data import PYTHON_CLIENT
 
 from archipelagos.common.data import is_valid_token
 
@@ -824,6 +825,7 @@ class FileStoreMetadataRequest:
         request.source = self._source
         request.code = self._code
         request.id = self._fs_id
+        request.clientType = PYTHON_CLIENT
 
         return request
 
@@ -1180,6 +1182,7 @@ class FileStoreRequest:
         request.code = self._code
         request.id = self._fs_id
         request.name = self._name
+        request.clientType = PYTHON_CLIENT
 
         return request
 
@@ -1574,6 +1577,8 @@ class FileMetadataRequest:
             request.patternSet = True
             request.pattern = self._pattern
 
+        request.clientType = PYTHON_CLIENT
+
         return request
 
     def serialize(self) -> bytes:
