@@ -14,6 +14,7 @@ from archipelagos.common.protobuf.common import Timestamp_pb2
 from archipelagos.common.data import _valid_feature_value, _feature_value_equals
 from archipelagos.common.data import _get_feature_value, _get_feature_value_from_proto
 from archipelagos.common.data import Frequency, is_valid_token
+from archipelagos.common.data import PYTHON_CLIENT
 
 import array
 from typing import Dict, List, Tuple, Any
@@ -1115,6 +1116,7 @@ class TimeSeriesMetadataRequest:
         request.source = self._source
         request.code = self._code
         request.id = self._ts_id
+        request.clientType = PYTHON_CLIENT
 
         return request
 
@@ -1655,6 +1657,7 @@ class TimeSeriesRequest:
         request.maxSize = self._max_size
         request.ascending = self._ascending
         request.filters.update(self._filters)
+        request.clientType = PYTHON_CLIENT
 
         return request
 
